@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -25,22 +22,15 @@ inline
 void
 log_det
   (
-  typename T1::elem_type& out_val,
-  typename T1::pod_type& out_sign,
+        typename T1::elem_type&          out_val,
+        typename T1::pod_type&           out_sign,
   const Base<typename T1::elem_type,T1>& X,
   const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
   )
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
-  
-  const unwrap<T1>   tmp(X.get_ref());
-  const Mat<eT>& A = tmp.M;
-  
-  arma_debug_check( !A.is_square(), "log_det(): matrix must be square" );
-  
-  auxlib::log_det(out_val, out_sign, A);
+  auxlib::log_det(out_val, out_sign, X);
   }
 
 
@@ -50,9 +40,9 @@ inline
 void
 log_det
   (
-  typename T1::elem_type& out_val,
-  typename T1::pod_type& out_sign,
-  const Op<T1,op_diagmat>& X,
+        typename T1::elem_type& out_val,
+        typename T1::pod_type&  out_sign,
+  const Op<T1,op_diagmat>&      X,
   const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
   )
   {
@@ -71,7 +61,7 @@ log_det
   
   T  sign = (is_complex<eT>::value == false) ? ( (access::tmp_real(x) < T(0)) ? -1 : +1 ) : +1;
   eT val  = (is_complex<eT>::value == false) ? std::log( (access::tmp_real(x) < T(0)) ? x*T(-1) : x ) : std::log(x);
-
+  
   for(u32 i=1; i<N; ++i)
     {
     const eT x = A[i];
